# Contributing

## Linting

Linting is run on the CI using [pre-commit](https://pre-commit.com/), and can be run
locally:

```sh
pip install pre-commit
pre-commit install  # optional: to run when you commit, on just the staged changes
pre-commit run --all-files  # to run on all files now
```

## Docstrings

Follow [Google style](https://google.github.io/styleguide/pyguide.html#38-comments-and-docstrings)
for docstrings.

## Localization

See [README](https://github.com/python-humanize/humanize#localization).
